@@ -1,5 +1,6 @@
 from ai_commit_msg.core.gen_commit_msg import generate_commit_message
 from ai_commit_msg.services.git_service import GitService
+from ai_commit_msg.services.pip_service import PipService
 from ai_commit_msg.utils.utils import execute_cli_command
 from ai_commit_msg.utils.error import AIModelHandlerError
 from ai_commit_msg.utils.logger import Logger
@@ -7,6 +8,8 @@ from ai_commit_msg.utils.logger import Logger
 def gen_ai_commit_message_handler():
     logger = Logger()
 
+    PipService().display_outdated_version_message()
+
     if(len(GitService.get_staged_files()) == 0):
       print("🚨 No files are staged for commit. Run `git add` to stage some of your changes")
       return
