@@ -1,6 +1,6 @@
 import time
 
-from ai_commit_msg.services.local_db_service import LocalDbService, CONFIG_COLLECTION_KEY
+from ai_commit_msg.services.local_db_service import ConfigKeysEnum, LocalDbService, CONFIG_COLLECTION_KEY
 from ai_commit_msg.utils.models import OPEN_AI_MODEL_LIST, ANTHROPIC_MODEL_LIST
 
 class ConfigService:
@@ -11,6 +11,7 @@ class ConfigService:
     ollama_url = "http://localhost:11434/api/chat"
     last_updated_at = ""
     prefix = ""
+    max_length = 50
 
     def __init__(self):
         config = ConfigService.get_config()
@@ -22,6 +23,7 @@ class ConfigService:
         if "ollama_url" in config: self.ollama_url = config["ollama_url"]
         if "last_updated_at" in config: self.last_updated_at = config["last_updated_at"]
         if "prefix" in config: self.prefix = config["prefix"]
+        if ConfigKeysEnum.MAX_LENGTH.value in config: self.max_length = config[ConfigKeysEnum.MAX_LENGTH.value]
 
     @staticmethod
     def get_config():
@@ -89,6 +91,12 @@ class ConfigService:
         LocalDbService().set_db({CONFIG_COLLECTION_KEY: config})
         self.prefix = prefix
 
+    def set_max_length(self, max_length):
+        config = ConfigService.get_config()
+        config[ConfigKeysEnum.MAX_LENGTH.value] = int(max_length)
+        LocalDbService().set_db({CONFIG_COLLECTION_KEY: config})
+        self.max_length = max_length
+
     @staticmethod
     def is_supported_model(model):
         # check if the model has ollama prefix
